﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using IntraSell_DLL;
using System.Windows.Forms;

namespace BankomatPaymentEcr
{
    /// <summary>
    /// Implements the Interface IntraSell_DLL.InterfacePaymentProvider to enable Intrasell with bankomat payments
    /// </summary>
    public class BankomatPaymentProvider : IntraSell_DLL.InterfacePaymentProvider
    {
        #region "Events"

        public event IntraSell_DLL.InterfacePaymentProvider.PurchaseOKEventHandler PurchaseOK;

        public virtual void OnPurchaseOK(decimal amount)
        {
            IntraSell_DLL.InterfacePaymentProvider.PurchaseOKEventHandler okHandler = PurchaseOK;
            if (okHandler != null)
            {
                okHandler(amount);
            }
            HideForm();
            btn.Enabled = true;

        }

        private void HideForm()
        {
            try
            {
                if (form != null)
                {
                    form.Hide();
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Hide form");
            }
        }

        public event IntraSell_DLL.InterfacePaymentProvider.PurchaseFailedEventHandler PurchaseFailed;

        public virtual void OnPurchaseFailed(string reason)
        {
            IntraSell_DLL.InterfacePaymentProvider.PurchaseFailedEventHandler failedHandler = PurchaseFailed;
            if (failedHandler != null)
            {
                failedHandler(reason);
            }
            HideForm();
            btn.Enabled = true;
        }
        public event IntraSell_DLL.InterfacePaymentProvider.PurchaseTimeoutEventHandler PurchaseTimeout;

        public virtual void OnPurchaseTimeout(EventArgs e)
        {
            IntraSell_DLL.InterfacePaymentProvider.PurchaseTimeoutEventHandler handler = PurchaseTimeout;
            if (handler != null)
            {
                handler();
            }

            HideForm();
            btn.Enabled = true;
        }

        public event IntraSell_DLL.InterfacePaymentProvider.BalanceOKEventHandler BalanceOK;
        public virtual void OnBalanceOK(string mechantRecepit)
        {
            IntraSell_DLL.InterfacePaymentProvider.BalanceOKEventHandler handler = BalanceOK;
            if (handler != null)
            {
                handler(mechantRecepit);
            }

            HideForm();
            btn.Enabled = true;
        }


        #endregion

        BankomatForm form;

        Button btn;

        public decimal amount { get; set; }

        public string currency { get; set; }

        public Button GetPaymentButton()
        {
            //if (btn == null)
            {
                btn = new System.Windows.Forms.Button();
                btn.BackgroundImage = global::BankomatPaymentEcr.Properties.Resources.MobileECR;
                btn.BackgroundImageLayout = System.Windows.Forms.ImageLayout.Zoom;
                btn.Width = 85;
                btn.Height = 65;
                btn.TextAlign = System.Drawing.ContentAlignment.BottomCenter;
                btn.Text = "Six Payment";
                btn.Click += btnSixPayment_Click;
            }
            return btn;
        }

        private void btnSixPayment_Click(object sender, EventArgs e)
        {
            try
            {
                btn.Enabled = false;
                if (form == null || form.IsDisposed)
                    form = new BankomatForm();
                //form.Show(); enable only for tests
                form.onPurchase(this, amount, "EUR");
            }
            catch (Exception ex)
            {
                OnPurchaseFailed(ex.Message);
            }
        }

        public void SetAmount(Decimal amount, string currency)
        {
            this.amount = amount;
            this.currency = currency;
        }

        public void Purchase(Decimal amount, string currency)
        {
            this.amount = amount;
            this.currency = currency;
            btnSixPayment_Click(null, null);
        }

        public void Cancel(Decimal amount)
        {
        }

        public void Balance()
        {
            try
            {
                btn.Enabled = false;
                if (form == null || form.IsDisposed)
                    form = new BankomatForm();
 
                form.onBalance(this);
            }
            catch (Exception ex)
            {
                OnPurchaseFailed(ex.Message);
            }
        }

        public void InitProvider()
        {
        }
        public void DisposeProvider()
        {
            try
            {
                if (form != null)
                {
                    form.DisposeTerminal();
                    form.Close();
                    form = null;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Dispose form");
            }
        }
    }
}
